==> nerdctl-debug-2.2.0-1-x86_64.pkg.tar.zst: usr/src/debug/nerdctl/nerdctl/cmd/nerdctl/namespace/namespace_update.go <==
/*
   Copyright The containerd Authors.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

package namespace

import (
	"github.com/spf13/cobra"

	"github.com/containerd/nerdctl/v2/cmd/nerdctl/completion"
	"github.com/containerd/nerdctl/v2/cmd/nerdctl/helpers"
	"github.com/containerd/nerdctl/v2/pkg/api/types"
	"github.com/containerd/nerdctl/v2/pkg/clientutil"
	"github.com/containerd/nerdctl/v2/pkg/cmd/namespace"
)

func updateCommand() *cobra.Command {
	cmd := &cobra.Command{
		Use:               "update [flags] NAMESPACE",
		Short:             "Update labels for a namespace",
		RunE:              updateAction,
		ValidArgsFunction: namespaceUpdateShellComplete,
		Args:              cobra.MinimumNArgs(1),
		SilenceUsage:      true,
		SilenceErrors:     true,
	}
	cmd.Flags().StringArrayP("label", "l", nil, "Set labels for a namespace")
	return cmd
}

func processNamespaceUpdateCommandOption(cmd *cobra.Command) (types.NamespaceUpdateOptions, error) {
	globalOptions, err := helpers.ProcessRootCmdFlags(cmd)
	if err != nil {
		return types.NamespaceUpdateOptions{}, err
	}
	labels, err := cmd.Flags().GetStringArray("label")
	if err != nil {
		return types.NamespaceUpdateOptions{}, err
	}
	return types.NamespaceUpdateOptions{
		GOptions: globalOptions,
		Labels:   labels,
	}, nil
}

func updateAction(cmd *cobra.Command, args []string) error {
	options, err := processNamespaceUpdateCommandOption(cmd)
	if err != nil {
		return err
	}

	client, ctx, cancel, err := clientutil.NewClient(cmd.Context(), options.GOptions.Namespace, options.GOptions.Address)
	if err != nil {
		return err
	}
	defer cancel()

	return namespace.Update(ctx, client, args[0], options)
}

func namespaceUpdateShellComplete(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
	return completion.NamespaceNames(cmd, args, toComplete)
}

==> nerdctl-debug-2.2.1-1-x86_64.pkg.tar.zst: usr/src/debug/nerdctl/nerdctl/cmd/nerdctl/namespace/namespace_update.go <==
/*
   Copyright The containerd Authors.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

package namespace

import (
	"github.com/spf13/cobra"

	"github.com/containerd/nerdctl/v2/cmd/nerdctl/completion"
	"github.com/containerd/nerdctl/v2/cmd/nerdctl/helpers"
	"github.com/containerd/nerdctl/v2/pkg/api/types"
	"github.com/containerd/nerdctl/v2/pkg/clientutil"
	"github.com/containerd/nerdctl/v2/pkg/cmd/namespace"
)

func updateCommand() *cobra.Command {
	cmd := &cobra.Command{
		Use:               "update [flags] NAMESPACE",
		Short:             "Update labels for a namespace",
		RunE:              updateAction,
		ValidArgsFunction: namespaceUpdateShellComplete,
		Args:              cobra.MinimumNArgs(1),
		SilenceUsage:      true,
		SilenceErrors:     true,
	}
	cmd.Flags().StringArrayP("label", "l", nil, "Set labels for a namespace (required)")
	cmd.MarkFlagRequired("label")
	return cmd
}

func processNamespaceUpdateCommandOption(cmd *cobra.Command) (types.NamespaceUpdateOptions, error) {
	globalOptions, err := helpers.ProcessRootCmdFlags(cmd)
	if err != nil {
		return types.NamespaceUpdateOptions{}, err
	}
	labels, err := cmd.Flags().GetStringArray("label")
	if err != nil {
		return types.NamespaceUpdateOptions{}, err
	}
	return types.NamespaceUpdateOptions{
		GOptions: globalOptions,
		Labels:   labels,
	}, nil
}

func updateAction(cmd *cobra.Command, args []string) error {
	options, err := processNamespaceUpdateCommandOption(cmd)
	if err != nil {
		return err
	}

	client, ctx, cancel, err := clientutil.NewClient(cmd.Context(), options.GOptions.Namespace, options.GOptions.Address)
	if err != nil {
		return err
	}
	defer cancel()

	return namespace.Update(ctx, client, args[0], options)
}

func namespaceUpdateShellComplete(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
	return completion.NamespaceNames(cmd, args, toComplete)
}
